@@ -163,7 +163,7 @@ void MainWindow::dragMoveEvent(QDragMoveEvent * event)
 
 bool MainWindow::loadPart()
 {
-    m_part = KPluginFactory::instantiatePlugin<KParts::ReadWritePart>(KPluginMetaData(QStringLiteral("kf" QT_STRINGIFY(QT_VERSION_MAJOR) "/parts/arkpart"))).plugin;
+    m_part = KPluginFactory::instantiatePlugin<KParts::ReadWritePart>(KPluginMetaData(QStringLiteral("kf6/parts/arkpart"))).plugin;
 
     if (!m_part) {
         KMessageBox::error(this, i18n("Unable to find Ark's KPart component, please check your installation."));
@@ -209,11 +209,7 @@ bool MainWindow::loadPart()
     hamburgerMenu->setMenuBar(menuBar());
 
     QAction *const showMenuBarAction = actionCollection()->action(
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        QLatin1String(KStandardAction::name(KStandardAction::ShowMenubar)));
-#else
         KStandardAction::name(KStandardAction::ShowMenubar));
-#endif
     hamburgerMenu->setShowMenuBarAction(showMenuBarAction);
 
     setXMLFile(QStringLiteral("arkui.rc"));
@@ -323,11 +319,7 @@ void MainWindow::updateHamburgerMenu()
 {
     const KActionCollection* ac = m_part->actionCollection();
     auto hamburgerMenu = static_cast<KHamburgerMenu *>(
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        ac->action(QLatin1String(KStandardAction::name(KStandardAction::HamburgerMenu))));
-#else
         ac->action(KStandardAction::name(KStandardAction::HamburgerMenu)));
-#endif
     auto menu = hamburgerMenu->menu();
     if (!menu) {
         menu = new QMenu(this);
@@ -338,11 +330,7 @@ void MainWindow::updateHamburgerMenu()
 
     if (!toolBar()->isVisible()) {
         // If neither the menu bar nor the toolbar are visible, these actions should be available.
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        menu->addAction(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::ShowMenubar))));
-#else
         menu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::ShowMenubar)));
-#endif
         menu->addAction(toolBarMenuAction());
         menu->addSeparator();
     }
