@@ -447,7 +447,7 @@ void BatchExtractJob::setupDestination()
         }
 
         if (d.exists(subfolderName)) {
-            subfolderName = KFileUtils::suggestName(QUrl::fromUserInput(m_destination, QString(), QUrl::AssumeLocalFile), subfolderName);
+            subfolderName = KFileUtils::suggestName(QUrl::fromUserInput(m_destination, QDir::currentPath(), QUrl::AssumeLocalFile), subfolderName);
         }
 
         d.mkdir(subfolderName);
