@@ -16,11 +16,7 @@ class Factory: public KPluginFactory
     Q_INTERFACES(KPluginFactory)
 
 protected:
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QObject *create(const char *iface, QWidget *parentWidget, QObject *parent, const QVariantList &args, const QString &keyword) override;
-#else
     QObject *create(const char *iface, QWidget *parentWidget, QObject *parent, const QVariantList &args) override;
-#endif
 };
 
 #endif
